%define major     1
%define libcmajor 2
%define libname   %mklibname %name %major
%define dlibname  %mklibname %name -d

Summary:	Constant Database
Name:		tinycdb
Version:	0.81
Release:	%mkrel 1
License:	Public Domain
Group:		Databases
URL:		https://www.corpit.ru/mjt/tinycdb.html
Source0:	https://www.corpit.ru/mjt/tinycdb/%{name}-%{version}.tar.gz
# taken from the 0.77 tarball
Source1:	libcdb.pc

%description
Tinycdb is a small, fast and reliable utility set and subroutine
library for creating and reading constant databases. The database
structure is tuned for fast reading:

 - Successful lookups take normally just two disk accesses.
 - Unsuccessful lookups take only one disk access.
 - Small disk space and memory size requirements; a database
   uses 2048 bytes for the header and 24 bytes plus size of
   (key,value) per record.
 - Maximum database size is 4GB; individual record size is not
   otherwise limited.
 - Portable file format.
 - Fast creation of new databases.
 - No locking, updates are atomic.

%package -n nss_%{name}
Summary:	Constant database library
Group:		System/Libraries

%description -n nss_%{name}
The tinycdb nss library allows creating passwd/group file using a
constant database.

%package -n %{libname}
Summary:	Constant database library
Group:		System/Libraries

%description -n %{libname}
Tinycdb is a small, fast and reliable utility set and subroutine
library for creating and reading constant databases. The database
structure is tuned for fast reading.

%package -n %{dlibname}
Summary:	Development libraries and headers for %{libname}
Group:		Development/Databases
Requires:	%{libname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{dlibname}
Libraries and header files needed to develop applications using
constant databases.

%prep
%setup -q

cp %{SOURCE1} .
# Fix libdir pathing in pkgconfig file.
sed -i -e 's\/lib\/%{_lib}\g' libcdb.pc

%build
%make_build CFLAGS="%{optflags}" \
            LDFLAGS="%{ldflags}" \
            staticlib sharedlib cdb-shared nss

%install
%make_install \
 libdir=%{_libdir} bindir=%{_bindir} mandir=%{_mandir} \
 syslibdir=/%{_lib} \
 includedir=%{_includedir} \
 install-all install-nss install-piclib install-sharedlib \
 INSTALLPROG=cdb-shared CP="cp -p"

mkdir -p %{buildroot}%{_libdir}/pkgconfig
install -m 0644 libcdb.pc %{buildroot}%{_libdir}/pkgconfig

rm -f %{buildroot}%{_sysconfdir}/cdb-Makefile

%files
%doc NEWS
%{_bindir}/cdb
%{_mandir}/man1/cdb.1*
%{_mandir}/man5/cdb.5*

%files -n nss_tinycdb
%doc nss_cdb-Makefile
/%{_lib}/libnss_cdb.so.%{libcmajor}

%files -n %{libname}
%{_libdir}/libcdb.so.%{major}

%files -n %{dlibname}
%{_includedir}/cdb.h
%{_libdir}/libcdb.a
%{_libdir}/libcdb_pic.a
%{_libdir}/libcdb.so
%{_libdir}/pkgconfig/libcdb.pc
%{_mandir}/man3/cdb.3*


%changelog
* Tue Feb 13 2024 daviddavid <daviddavid> 0.81-1.mga10
+ Revision: 2040953
- new version: 0.81

* Tue Dec 05 2023 daviddavid <daviddavid> 0.80-1.mga10
+ Revision: 2013419
- new version: 0.80

* Tue Mar 15 2022 umeabot <umeabot> 0.78-3.mga9
+ Revision: 1792493
- Mageia 9 Mass Rebuild

* Fri Feb 14 2020 umeabot <umeabot> 0.78-2.mga8
+ Revision: 1520231
- Mageia 8 Mass Rebuild

* Thu Nov 08 2018 daviddavid <daviddavid> 0.78-1.mga7
+ Revision: 1328943
- new version: 0.78
- fix libdir pathing in pkgconfig file

* Sun Sep 23 2018 umeabot <umeabot> 0.77-8.mga7
+ Revision: 1301417
- Mageia 7 Mass Rebuild

* Mon Feb 08 2016 umeabot <umeabot> 0.77-7.mga6
+ Revision: 942595
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.77-6.mga5
+ Revision: 738901
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.77-5.mga5
+ Revision: 689895
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0.77-4.mga4
+ Revision: 519648
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 0.77-3.mga3
+ Revision: 384586
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Oct 13 2012 fwang <fwang> 0.77-2.mga3
+ Revision: 305195
- new devel package policy

* Sat Jan 22 2011 ennael <ennael> 0.77-2.mga1
+ Revision: 33024
- remove mdk version
- imported package tinycdb


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 0.77-2mdv2011.0
+ Revision: 607999
- rebuild

* Sun Jan 24 2010 Luca Berra <bluca@mandriva.org> 0.77-1mdv2010.1
+ Revision: 495485
- new version 0.77

* Wed Sep 09 2009 Thierry Vignaud <tv@mandriva.org> 0.74-8mdv2010.0
+ Revision: 434389
- rebuild

* Sun Aug 03 2008 Thierry Vignaud <tv@mandriva.org> 0.74-7mdv2009.0
+ Revision: 261542
- rebuild

* Wed Jul 30 2008 Thierry Vignaud <tv@mandriva.org> 0.74-6mdv2009.0
+ Revision: 254562
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Dec 17 2007 Thierry Vignaud <tv@mandriva.org> 0.74-4mdv2008.1
+ Revision: 128462
- kill re-definition of %%buildroot on Pixel's request
- import tinycdb


* Sun Aug 28 2005 Luca Berra <bluca@vodka.it> 0.74-4mdk
- rebuild

* Fri Apr 15 2005 Luca Berra <bluca@vodka.it> 0.74-3mdk
- %%mkrel tag, rebuild

* Wed Feb 25 2004 Luca Berra <bluca@vodka.it> 0.74-2mdk
- CFL: cdb-devel

* Mon Jan 19 2004 Luca Berra <bluca@vodka.it> 0.74-1mdk
- Initial mandrake contrib
